@@ -55,7 +55,7 @@ class Admin(Vault):
             print("Status 200:  Running Setup...")
             self.set_vault()
             self.__mount_ssh_backend()
-            self.__write_signing_key()
+            self.write_signing_key()
             self.__create_signing_role()
             self.__create_token_role()
 
@@ -72,7 +72,7 @@ class Admin(Vault):
 
     # --- SSH Keys ---
 
-    def __write_signing_key(self, public_key=None, private_key=None):
+    def write_signing_key(self, public_key=None, private_key=None):
         signing_key_address = "%s/config/ca" % MOUNT_POINT
         try:
             public_key = self.config["admin"]["publicSigningKey"]
@@ -85,7 +85,6 @@ class Admin(Vault):
     
         try:
             if not public_key and not private_key:
-                # self.vault.write(signing_key_address, generate_signing_key=True)
                 key_dict = self.__generate_signing_key()
                 public_key = key_dict["public_key"]
                 private_key = key_dict["private_key"]
@@ -98,8 +97,16 @@ class Admin(Vault):
                 "publicSigningKey": public_key,
                 "privateSigningKey": private_key
             })
-        except InvalidRequest:
-            print("Signing Key already written...")
+        except InvalidRequest as error:
+            if "keys are already configured" in error:
+                print("Signing Key already written...")
+            else:
+                raise
+            
+
+    def delete_signing_key(self):
+        signing_key_address = "%s/config/ca" % MOUNT_POINT
+        self.vault.delete(signing_key_address)
 
     def __generate_signing_key(self):
         ssh_loc = "/Users/%s/.ssh" % getpass.getuser()
@@ -108,8 +115,8 @@ class Admin(Vault):
         with open("%s/%s.pub" % (ssh_loc, key_name), 'r') as public_file:
             public_key = public_file.read().replace('\n', '')
             public_file.close()
-        with open("%s/%s.pub" % (ssh_loc, key_name), 'r') as private_file:
-            private_key = private_file.read().replace('\n', '')
+        with open("%s/%s" % (ssh_loc, key_name), 'r') as private_file:
+            private_key = private_file.read()
             private_file.close()
         return {
             "public_key": public_key,
