@@ -1,4 +1,3 @@
-import subprocess
 from os import environ
 from os.path import isfile, join
 import getpass
@@ -29,10 +28,10 @@ class Refresh(Vault):
     def gen_ssh_key(self):
         print("Generating Key Pair...")
         if isfile(self.pubkey_path): ## keypair exists but is stale
-            self.command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096  -N '' -f %s/%s 2>/dev/null <<< y >/dev/null" % (self.ssh_loc, self.key_name))
+            self._command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096  -N '' -f %s/%s 2>/dev/null <<< y >/dev/null" % (self.ssh_loc, self.key_name))
 
         else: ## keypair does not exist
-            self.command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096 -f %s/%s -N ''" % (self.ssh_loc, self.key_name))
+            self._command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096 -f %s/%s -N ''" % (self.ssh_loc, self.key_name))
 
     def request_certificate(self):
         with open(self.pubkey_path, 'r') as pubkey:
@@ -110,34 +109,3 @@ class Refresh(Vault):
             return token
         except KeyError:
             raise Exception("Variable: %s could not be found in environment" % new_variable)
-        
-
-    def command(self, com_string, silent=True, env=environ.copy()):
-        process = subprocess.Popen(
-            com_string,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            shell=True,
-            env=env
-        )
-        output = process.communicate()
-        if not silent:
-            print("Running Command: %s" % com_string)
-            self.print_bytes(output[0])
-        try:
-            string_output = [x.decode("utf-8") for x in output]
-        except AttributeError:
-            string_output = output
-        if string_output[1] and "SNIMissingWarning" not in string_output[1] and "insecure" not in string_output[1].lower():
-            print("Errors:")
-            self.print_bytes(string_output[1])
-            raise Exception(string_output[1])
-        return output
-
-    @staticmethod
-    def print_bytes(byte_string):
-        if isinstance(byte_string, bytes):
-            byte_string = byte_string.decode('utf-8')
-        string_list = byte_string.split("/n")
-        for string_item in string_list:
-            print(string_item)
