@@ -108,14 +108,14 @@ class Vault(object):
         output = process.communicate()
         if not silent:
             print("Running Command: %s" % com_string)
-            self.print_bytes(output[0])
+            self._print_bytes(output[0])
         try:
             string_output = [x.decode("utf-8") for x in output]
         except AttributeError:
             string_output = output
         if string_output[1] and "SNIMissingWarning" not in string_output[1] and "insecure" not in string_output[1].lower():
             print("Errors:")
-            self.print_bytes(string_output[1])
+            self._print_bytes(string_output[1])
             raise Exception(string_output[1])
         return output
 
